{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
  {% if not is_popup %}
    <p>{% trans 'First, enter an email address and password. Then, you’ll be able to edit more user options.' %}</p>
  {% else %}
    <p>{% trans "Enter an email address and password." %}</p>
  {% endif %}
{% endblock %}
